﻿#region Copyright
/// <summary>The ScummVM WPF UI project</summary>
/// <copyright>(c) 2016 MojoTouch</copyright>
/// <author>Ilya Rovensky</author>
#endregion

using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;

namespace WpfInterface
{
    public partial class SettingsSubMenu : Menu
    {
        private List<Setting> _settings;

        public SettingsSubMenu(List<Setting> settings)
        {
            InitializeComponent();

            BackButton.Focus();

            _settings = settings;
            for (int settingIndex = 0; settingIndex < settings.Count; settingIndex++)
            //foreach (Setting setting in settings)
            {
                Setting setting = settings[settingIndex];

                if (setting is RadioSetting)
                {
                    StackPanel parentPanel = new StackPanel();

                    for (int i = 0; i < ((RadioSetting)setting).ItemNames.Count; i++)
                    {
                        RadioButton radioButton = new RadioButton()
                        {
                            Style = (Style)FindResource("RadioButtonMain"),
                            Tag = new KeyValuePair<int, int>(i, settingIndex),
                            Content = ((RadioSetting)setting).ItemNames[i],
                            HorizontalContentAlignment = HorizontalAlignment.Left,
                            IsChecked = i == setting.Value
                        };
                        radioButton.Click += Button_Click;
                        parentPanel.Children.Add(radioButton);
                    }

                    PlaceholderPanel.Children.Add(parentPanel);
                }
                else if (setting is SliderSetting)
                {
                    DockPanel parentPanel = new DockPanel();

                    SliderSetting sliderSetting = (SliderSetting)setting;

                    //parentPanel.Orientation = Orientation.Horizontal;
                    parentPanel.Margin = new Thickness(0, 20, 0, 0);

                    TextBlock textBlock = new TextBlock()
                    {
                        //Style = (Style)FindResource("OptionMarkFocusVisual"),
                        Style = (Style)FindResource("TextBlockStyle"),
                        //HorizontalAlignment = HorizontalAlignment.Left,
                        Text = sliderSetting.Title
                    };

                    DockPanel.SetDock(textBlock, Dock.Left);
                    parentPanel.Children.Add(textBlock);

                    Slider slider = new Slider()
                    {
                        Style = (Style)FindResource("SliderMain"),
                        //Tag = setting,
                        Tag = settingIndex,
                        MinWidth = 150,
                        HorizontalAlignment = HorizontalAlignment.Stretch,
                        Minimum = sliderSetting.MinValue,
                        Maximum = sliderSetting.MaxValue,
                        Value = sliderSetting.Value
                    };
                    slider.ValueChanged += (sender, _) => { Button_Click(sender, null); };
                    
                    parentPanel.Children.Add(slider);
                    PlaceholderPanel.Children.Add(parentPanel);
                }
                                
                PlaceholderPanel.Children.Remove(BackButton);
                PlaceholderPanel.Children.Add(BackButton);
            }
        }

        public void ShowAgain(List<Setting> settings)
        {
            _settings = settings;
            ShowAgain();
        }

        protected override void StringsChanged()
        {
            BackButton.Content = Strings[(int)LocString.back];
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            FrameworkElement element = (FrameworkElement)sender;
            
            // if it is not back button, set values
            if (element.Tag != null)
            {
                if (element is Slider)
                    _settings[(int)element.Tag].Value = (int)(element as Slider).Value;
                    //((Setting)element.Tag).Value = (int)(element as Slider).Value;
                else // radio button
                {
                    KeyValuePair<int, int> pair = (KeyValuePair<int, int>)element.Tag;
                    _settings[pair.Value].Value = pair.Key;
                }                

                Result = MenuAction.SettingsVoice; // not really matters
            }
            else
                Result = MenuAction.Settings;

            BackButton.Focus();
        }
    }
}
